nxp-pac

Crates

git

Versions

mimxrt685s_cm33

Flavors

Intval

Struct Intval 

#[repr(transparent)]
pub struct Intval(pub u32);
MRT Time interval value register. This value is loaded into the TIMER register.

Tuple Fields

0: u32

Implementations

Source

impl Intval

pub const fn ivalue(&self) -> u32

Time interval load value. This value is loaded into the TIMERn register and the MRT channel n starts counting down from IVALUE -1. If the timer is idle, writing a non-zero value to this bit field starts the timer immediately. If the timer is running, writing a zero to this bit field does the following: If LOAD = 1, the timer stops immediately. If LOAD = 0, the timer stops at the end of the time interval.

pub const fn set_ivalue(&mut self, val: u32)

Time interval load value. This value is loaded into the TIMERn register and the MRT channel n starts counting down from IVALUE -1. If the timer is idle, writing a non-zero value to this bit field starts the timer immediately. If the timer is running, writing a zero to this bit field does the following: If LOAD = 1, the timer stops immediately. If LOAD = 0, the timer stops at the end of the time interval.

pub const fn load(&self) -> bool

Determines how the timer interval value IVALUE -1 is loaded into the TIMERn register. This bit is write-only. Reading this bit always returns 0.

pub const fn set_load(&mut self, val: bool)

Determines how the timer interval value IVALUE -1 is loaded into the TIMERn register. This bit is write-only. Reading this bit always returns 0.