#[repr(transparent)]pub struct Timer(pub u32);Expand description
MRT Timer register. This register reads the value of the down-counter.
Tuple Fields
0: u32Implementations
Sourceimpl Timer
impl Timer
Sourcepub const fn value(&self) -> u32
pub const fn value(&self) -> u32
Holds the current timer value of the down-counter. The initial value of the TIMERn register is loaded as IVALUE - 1 from the INTVALn register either at the end of the time interval or immediately in the following cases: INTVALn register is updated in the idle state. INTVALn register is updated with LOAD = 1. When the timer is in idle state, reading this bit fields returns -1 (0x00FF FFFF).
Sourcepub const fn set_value(&mut self, val: u32)
pub const fn set_value(&mut self, val: u32)
Holds the current timer value of the down-counter. The initial value of the TIMERn register is loaded as IVALUE - 1 from the INTVALn register either at the end of the time interval or immediately in the following cases: INTVALn register is updated in the idle state. INTVALn register is updated with LOAD = 1. When the timer is in idle state, reading this bit fields returns -1 (0x00FF FFFF).